package com.flossom.system.service;


import com.flossom.common.core.domain.entity.WxUserMember;
import com.flossom.common.core.domain.req.WxUserMemberVm;

import java.util.List;

/**
 * 用户Service接口
 * 
 * @author flossom
 * @date 2023-12-08
 */
public interface IWxUserMemberService 
{
    /**
     * 查询用户
     * 
     * @param id 用户主键
     * @return 用户
     */
    public WxUserMember selectWxUserMemberById(Long id);

    /**
     * 查询用户列表
     * 
     * @param wxUserMember 用户
     * @return 用户集合
     */
    public List<WxUserMember> selectWxUserMemberList(WxUserMember wxUserMember);

    /**
     * 查询用户列表
     *
     * @param wxUserMemberVm 用户
     * @return 用户集合
     */
    public List<WxUserMember> selectWxUserMemberList(WxUserMemberVm wxUserMemberVm);

    /**
     * 新增用户
     * 
     * @param wxUserMember 用户
     * @return 结果
     */
    public int insertWxUserMember(WxUserMember wxUserMember);

    /**
     * 修改用户
     * 
     * @param wxUserMember 用户
     * @return 结果
     */
    public int updateWxUserMember(WxUserMember wxUserMember);

    /**
     * 批量删除用户
     * 
     * @param ids 需要删除的用户主键集合
     * @return 结果
     */
    public int deleteWxUserMemberByIds(Long[] ids);

    /**
     * 删除用户信息
     * 
     * @param id 用户主键
     * @return 结果
     */
    public int deleteWxUserMemberById(Long id);
}
